# Copyright (C) 2017  Eike Tim Jesinghaus <eike@naturalnet.de>
# Copyright (C) 2017  Dominik George <nik@naturalnet.de>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from veripeditus import framework as f

# Some mandatory meta-data about the game
NAME = 'Bike thiefs at FOSDEM'
DESCRIPTION = 'Be a not so nice guy and help a thief steal some bikes to get some stuff back'
AUTHOR = 'Dominik George <nik@naturalnet.de>, Eike Tim Jesinghaus <eike@naturalnet.de>'
LICENSE = 'AGPL-3+'
VERSION = '0.1'

HIDE_SELF = True
VISIBLE_RAD_PLAYERS = 0

class Player(f.Player):
    pass

class Smartphone(f.Item):
    default_image = "item_smartphone"
    default_name = "Smartphone"

class Beer(f.Item):
    default_image = "item_beer"
    default_name = "Beer"

class Bike(f.Item):
    default_image = "item_bike"
    default_name = "Bike"
    spawn_latlon = (50.8137553, 4.3832699)
    owned_max = 4
    distance_max = 30

    def may_collect(self, player):
        if player.has_item(Keycard):
            return True
        else:
            return False

class Keycard(f.Item):
    default_image = "item_keycard"
    default_name = "Key card"

class Food(f.Item):
    default_image = "item_food"
    default_name = "Food"

class Coin(f.Item):
    default_image = "item_coin"
    default_name = "coin"
    spawn_latlon = [(50.813811, 4.3816217), (50.8138539, 4.3821253), (50.8144007, 4.3816449), (50.813811, 4.3816217)]
    spawn_max = 1
    owned_max = 4
    distance_max = 30

class Nerd(f.NPC):
    default_image = "npc_nerd"
    default_name = "Nerd"
    spawn_latlon = (50.8148805, 4.3814313)
    distance_max = 30

    def on_talk(self):
        player = f.current_player()
        if player.has_item(Smartphone):
            msg = "Thank you for bringing back my smartphone! Have a beer!"
            player.drop_items(Smartphone)
            player.new_item(Beer)
        else:
            if player.has_item(Beer):
                msg = "Thanks!"
            else:
                msg = "A thief stole my smartphone! I believe he ran towards Janson..."
        return self.say(msg)

class Thief(f.NPC):
    default_image = "npc_thief"
    default_name = "Thief"
    spawn_latlon = (50.8131082, 4.37914)
    distance_max = 30

    def on_talk(self):
        player = f.current_player()
        if player.has_item(Bike) == 3:
            msg = "Okay, gimme those bikes! Here, you can have your smartphone back!"
            player.drop_items(Bike)
            player.new_item(Smartphone)
        else:
            if player.has_item(Beer) or player.has_item(Smartphone):
                msg = "You already have your smartphone back."
            else:
                msg = "You want your smartphone back? Huh, I guess we could trade... Get me 3 bikes! 3! Then you can have your smartphone! Try to talk some hacker at the data center into making you a key card for the bike shed..."
        return self.say(msg)

class Hacker(f.NPC):
    default_image = "npc_hacker"
    default_name = "Hacker"
    spawn_latlon = (50.8143262, 4.3828322)
    distance_max = 30

    def on_talk(self):
        player = f.current_player()
        if player.has_item(Food):
            msg = "Thanks for the food, here you have a key card!"
            player.drop_items(Food)
            player.new_item(Keycard)
        else:
            if player.has_item(Keycard):
                msg = "What do you want? You already have a key card."
            else:
                msg = "You want a key card for the bike shed? Get me some food, then let's see..."
        return self.say(msg)

class Merchant(f.NPC):
    default_image = "npc_merchant"
    default_name = "Merchant"
    spawn_latlon = (50.8129086, 4.3817163)
    distance_max = 30

    def on_talk(self):
        player = f.current_player()
        if player.has_item(Coin) >= 3:
            msg = "Here you have some food!"
            player.drop_items(Coin)
            player.new_item(Food)
        else:
            msg = "You can have some food for 3 coins! I saw someone loosing their money on the lawn next to the K building..."
        return self.say(msg)
